aboutsummaryrefslogtreecommitdiff
path: root/map.h
diff options
context:
space:
mode:
Diffstat (limited to 'map.h')
-rw-r--r--map.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/map.h b/map.h
index c580cb3..09e5c90 100644
--- a/map.h
+++ b/map.h
@@ -9,8 +9,8 @@
/* Returns an empty map of given size */
Map empty_map(size_t width, size_t height);
-/* Stores all the existing neighbours of pos in neighbour_array and returns their amount */
-unsigned int neighbours(Position neighbour_array[], Position pos, size_t width, size_t height, \
+/* Stores all the existing 4dir neighbours of pos in neighbour_array and returns their amount */
+unsigned int neighbours_4dir(Position neighbour_array[], Position pos, size_t width, size_t height, \
char visited[height][width]);
/* https://en.wikipedia.org/wiki/Maze_generation_algorithm#Randomized_depth-first_search